"use strict";
// ~~ Generated by projen. To modify, edit .projenrc.js and run "yarn projen".
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __exportStar = (this && this.__exportStar) || function(m, exports) {
    for (var p in m) if (p !== "default" && !Object.prototype.hasOwnProperty.call(exports, p)) __createBinding(exports, m, p);
};
Object.defineProperty(exports, "__esModule", { value: true });
/* eslint-disable import/no-extraneous-dependencies -- re-exports the build-time-only @aws-cdk/private-tools package */
/* eslint-disable no-restricted-imports -- this shim is the single sanctioned entry point to @aws-cdk/private-tools */
__exportStar(require("@aws-cdk/private-tools/lib/zip"), exports);
//# sourceMappingURL=data:application/json;base64,eyJ2ZXJzaW9uIjozLCJmaWxlIjoidG9vbHMuanMiLCJzb3VyY2VSb290IjoiIiwic291cmNlcyI6WyJ0b29scy50cyJdLCJuYW1lcyI6W10sIm1hcHBpbmdzIjoiO0FBQUEsOEVBQThFOzs7Ozs7Ozs7Ozs7Ozs7O0FBRTlFLHVIQUF1SDtBQUN2SCxzSEFBc0g7QUFDdEgsaUVBQStDIiwic291cmNlc0NvbnRlbnQiOlsiLy8gfn4gR2VuZXJhdGVkIGJ5IHByb2plbi4gVG8gbW9kaWZ5LCBlZGl0IC5wcm9qZW5yYy5qcyBhbmQgcnVuIFwieWFybiBwcm9qZW5cIi5cblxuLyogZXNsaW50LWRpc2FibGUgaW1wb3J0L25vLWV4dHJhbmVvdXMtZGVwZW5kZW5jaWVzIC0tIHJlLWV4cG9ydHMgdGhlIGJ1aWxkLXRpbWUtb25seSBAYXdzLWNkay9wcml2YXRlLXRvb2xzIHBhY2thZ2UgKi9cbi8qIGVzbGludC1kaXNhYmxlIG5vLXJlc3RyaWN0ZWQtaW1wb3J0cyAtLSB0aGlzIHNoaW0gaXMgdGhlIHNpbmdsZSBzYW5jdGlvbmVkIGVudHJ5IHBvaW50IHRvIEBhd3MtY2RrL3ByaXZhdGUtdG9vbHMgKi9cbmV4cG9ydCAqIGZyb20gJ0Bhd3MtY2RrL3ByaXZhdGUtdG9vbHMvbGliL3ppcCc7XG4iXX0=