"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.startLspServer = exports.cdkLspManifest = void 0;
/* eslint-disable import/no-extraneous-dependencies -- re-exports the build-time-only @aws-cdk/private-tools package */
var cdk_explorer_1 = require("@aws-cdk/cdk-explorer");
Object.defineProperty(exports, "cdkLspManifest", { enumerable: true, get: function () { return cdk_explorer_1.cdkLspManifest; } });
Object.defineProperty(exports, "startLspServer", { enumerable: true, get: function () { return cdk_explorer_1.startLspServer; } });
//# sourceMappingURL=data:application/json;base64,eyJ2ZXJzaW9uIjozLCJmaWxlIjoiZXhwbG9yZXIuanMiLCJzb3VyY2VSb290IjoiIiwic291cmNlcyI6WyJleHBsb3Jlci50cyJdLCJuYW1lcyI6W10sIm1hcHBpbmdzIjoiOzs7QUFBQSx1SEFBdUg7QUFDdkgsc0RBQXVFO0FBQTlELDhHQUFBLGNBQWMsT0FBQTtBQUFFLDhHQUFBLGNBQWMsT0FBQSIsInNvdXJjZXNDb250ZW50IjpbIi8qIGVzbGludC1kaXNhYmxlIGltcG9ydC9uby1leHRyYW5lb3VzLWRlcGVuZGVuY2llcyAtLSByZS1leHBvcnRzIHRoZSBidWlsZC10aW1lLW9ubHkgQGF3cy1jZGsvcHJpdmF0ZS10b29scyBwYWNrYWdlICovXG5leHBvcnQgeyBjZGtMc3BNYW5pZmVzdCwgc3RhcnRMc3BTZXJ2ZXIgfSBmcm9tICdAYXdzLWNkay9jZGstZXhwbG9yZXInO1xuIl19