import type * as https from 'node:https';
import type { Settings } from '../api/settings';
import type { IoHelper } from '../api-private';
export interface DoctorOptions {
    readonly ioHelper: IoHelper;
    /**
     * The resolved CLI settings, used to report the active CLI configuration
     * (debug targets, verbosity, ...).
     *
     * @default - configuration is not reported
     */
    readonly settings?: Settings;
    /**
     * The agent used for the network request of the version check
     *
     * Use this to set up a proxy connection.
     *
     * @default - the shared global node agent
     */
    readonly agent?: https.Agent;
}
export declare function doctor({ ioHelper, settings, agent }: DoctorOptions): Promise<number>;
